/* ADDICON.CMD Version 1.0 */
/* by Timothy F. Sipples */
/* July 11, 1992 */

/* Copyright 1992 by Timothy F. Sipples. */
/* This utility may be freely distributed with all included files. */
/* For-profit (commercial) users: please see the accompanying */
/* documentation for license terms. */

/* ADDICON is a REXX utility to attach an icon file to any file */
/* on the system.  It uses the SysSetIcon function in REXX, which */
/* places the icon file in the extended attributes of any given */
/* file. */

/* Retrieve command line arguments passed to program. */
/* Also converts to uppercase. */
ARG Arg1 Arg2

/* Print title banner. */
SAY ''
SAY 'AddIcon Version 1.0 for OS/2 Version 2.0 and Above'
SAY 'by Timothy F. Sipples (Internet: sip1@ellis.uchicago.edu)'
SAY ''

/* Check for null arguments. */
if Arg1 \= '' & Arg2 \= '' then SIGNAL attach

/* If one or both arguments not specified, print usage information. */
SAY 'USAGE:    ADDICON Iconfile Filename'
SAY ''
SAY "Iconfile, an icon file created by OS/2's Icon Editor,"
SAY "will be added to Filename's extended attributes."
SAY ''
SAY 'Example:  ADDICON \ICONS\DOC.ICO C:\DATA\TEST.TXT'
SAY ''
SAY 'Wildcards are not permitted.  However, a single icon may be'
SAY 'attached to multiple files using the FOR..DO command (see the'
SAY 'online Command Reference for details).'
SAY ''
SAY 'Example:  FOR %1 IN (C:\DATA\*.TXT) DO ADDICON \ICONS\DOC.ICO %1'
SIGNAL end

attach:

/* Load SysSetIcon function from standard OS/2 REXX library. */
call RxFuncAdd 'SysSetIcon','RexxUtil','SysSetIcon'

/* Attempt to attach icon. */
if SysSetIcon(Arg2,Arg1) then DO
     SAY 'Icon 'Arg1
     SAY 'successfully attached to file 'Arg2'.'
     END
     else SIGNAL failed

end:
SAY ''
EXIT

failed:
SAY 'ERROR:'
SAY 'Unable to attach icon 'Arg1
SAY 'to file 'Arg2'.'
SAY ''
SAY 'Verify that both files exist, that the icon file is in the'
SAY 'proper format, and that files are not in use by another process.'
SIGNAL end
